Package: scdhlm
Title: Estimating Hierarchical Linear Models for Single-Case Designs
Version: 0.7.4
Authors@R: c(
    person("James", "Pustejovsky", email = "jepusto@gmail.com", role = c("aut", "cre")),
    person("Man", "Chen", role = "aut"), 
    person("Bethany", "Hamilton", role = "aut")
	)
Description: Provides a set of tools for estimating hierarchical linear
    models and effect sizes based on data from single-case designs. 
    Functions are provided for calculating standardized mean difference effect sizes that 
    are directly comparable to standardized mean differences estimated from between-subjects randomized experiments,
    as described in Hedges, Pustejovsky, and Shadish (2012) <DOI:10.1002/jrsm.1052>; 
    Hedges, Pustejovsky, and Shadish (2013) <DOI:10.1002/jrsm.1086>; 
    Pustejovsky, Hedges, and Shadish (2014) <DOI:10.3102/1076998614547577>; 
    and Chen, Pustejovsky, Klingbeil, and Van Norman (2023) <DOI:10.1016/j.jsp.2023.02.002>. 
    Includes an interactive web interface.
URL: https://jepusto.github.io/scdhlm/
BugReports: https://github.com/jepusto/scdhlm/issues
License: GPL-3
VignetteBuilder: knitr
LazyData: true
Imports: stats, utils, readxl, rlang, dplyr, tidyselect, magrittr,
        lmeInfo (>= 0.3.0)
Depends: nlme, R (>= 3.0.1)
Suggests: knitr, markdown, rmarkdown, ggplot2, plyr, boot, parallel,
        shiny, shinytest, glue, janitor, rclipboard, rvest, testthat,
        snow, doSNOW, foreach, iterators, reshape, rlecuyer
RoxygenNote: 7.3.3
Encoding: UTF-8
Language: en-US
NeedsCompilation: no
Packaged: 2026-01-21 20:17:14 UTC; jamespustejovsky
Author: James Pustejovsky [aut, cre],
  Man Chen [aut],
  Bethany Hamilton [aut]
Maintainer: James Pustejovsky <jepusto@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-21 20:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 15:00:46 UTC; unix
