# Generated by roxygen2: do not edit by hand

S3method(CI_g,g_HPS)
S3method(CI_g,g_REML)
S3method(print,g_HPS)
S3method(print,g_REML)
S3method(simulate,g_REML)
S3method(summary,g_HPS)
S3method(summary,g_REML)
export(CI_g)
export(Info_Expected_lmeAR1)
export(batch_calc_BCSMD)
export(calc_BCSMD)
export(compare_RML_HPS)
export(default_times)
export(design_matrix)
export(effect_size_ABk)
export(effect_size_MB)
export(extract_varcomp)
export(g_REML)
export(g_mlm)
export(graph_SCD)
export(phase_pairs)
export(preprocess_SCD)
export(session_by_treatment)
export(shine_scd)
export(simulate_MB2)
export(simulate_MB4)
export(varcomp_vcov)
import(nlme)
import(stats)
importFrom(dplyr,.data)
importFrom(lmeInfo,CI_g)
importFrom(lmeInfo,extract_varcomp)
importFrom(lmeInfo,g_mlm)
importFrom(lmeInfo,varcomp_vcov)
importFrom(magrittr,"%>%")
importFrom(readxl,read_excel)
importFrom(rlang,"!!!")
importFrom(rlang,"!!")
