
# Calculate effect size
res <- effect_size_MB(outcome = {user_outcome}, 
                      treatment = trt, 
                      id = {user_case}, 
                      time = {user_session},
                      data = dat) 
res
