# Graph 
graph_SCD(design = "{user_design}", 
          case = {user_case}, phase = {user_phase}, 
          session = {user_session}, outcome = {user_outcome}, {furtherArg_method} {furtherArg_design} 
          data = dat)

