### Example data

* Alber-Morgan, S. R., Ramp, E. M., Anderson, L. L., & Martin, C. M. (2007). Effects of repeated readings, error correction, and performance feedback on the fluency and comprehension of middle school students with behavior problems. *Journal of Special Education, 41*(1), 17-30.
DOI: [10.1177/00224669070410010201](http://dx.doi.org/10.1177/00224669070410010201)

* Anglesea, M. M., Hoch, H., & Taylor, B. A. (2008). Reducing rapid eating in teenagers with autism: Use of a pager prompt. *Journal of Applied Behavior Analysis, 41*(1), 107-111. DOI: [10.1901/jaba.2008.41-107](http://dx.doi.org/10.1901/jaba.2008.41-107)

* Barton-Arwood, S. M., Wehby, J. H., & Falk, K. B. (2005). Reading instruction for elementary-age students with emotional and behavioral disorders: Academic and behavioral outcomes. *Exceptional Children, 72*(1), 7-27. DOI: [10.1177/001440290507200101](https://doi.org/10.1177/001440290507200101)

* Bryant, D. R., Bryant, B. R., Sorelle-Miner, D. A., Falcomata, T. S. & Nozari, M. (2018). Tier 3 intensified intervention for second grade students with severe mathematics difficulties. *Archives of Psychology, 2*(11), 1-24. DOI:[10.31296/aop.v2i11.86](https://archivesofpsychology.org/index.php/aop/article/view/86)

* Case, L. P., Harris, K. R., & Graham, S. (1992). Improving the mathematical problem-solving skills of students with learning disabilities: Self-regulated strategy development. *The Journal of Special Education, 26*(1), 1-19. DOI: [10.1177/002246699202600101](https://doi.org/10.1177/002246699202600101)

* Datchuk, S. M. (2016). Writing simple sentences and descriptive paragraphs: Effects of an intervention on adolescents with writing difficulties. *Journal of Behavioral Education, 25*(2), 166-188. DOI: [10.1007/s10864-015-9236-x](https://doi.org/10.1007/s10864-015-9236-x)

* Delemere, E., & Dounavi, K. (2018). Parent-implemented bedtime fading and positive routines for children with autism spectrum disorders. *Journal of Autism and Developmental Disorders, 48*(4), 1002-1019. DOI: [10.1007/s10803-017-3398-4](https://doi.org/10.1007/s10803-017-3398-4)

* Gunning, M. J., & Espie, C.A. (2003). Psychological treatment of reported sleep disorder in adults with intellectual disability using a multiple baseline design. *Journal of Intellectual Disability Research, 47*(3), 191-202. DOI: [10.1046/j.1365-2788.2003.00461.x](https://doi.org/10.1046/j.1365-2788.2003.00461.x)

* Lambert, M. C., Cartledge, G., Heward, W. L., & Lo, Y. (2006). Effects of response cards on disruptive behavior and academic responding during math lessons by fourth-grade urban students. *Journal of Positive Behavior Interventions, 8*(2), 88-99. DOI: [10.1177/10983007060080020701](https://doi.org/10.1177/10983007060080020701)

* Laski, K. E., Charlop, M. H., & Schreibman, L. (1988). Training parents to use the natural language paradigm to increase their autistic children's speech. *Journal of Applied Behavior Analysis, 21*(4), 391-400. DOI: [10.1901/jaba.1988.21-391](https://doi.org/10.1901/jaba.1988.21-391)

* Peltier, C., Sinclair, T. E., Pulos, J. M., & Suk, A. (2020). Effects of schema-based instruction on immediate, generalized, and combined structured word problems. *The Journal of Special Education, 54*(2), 101-112. DOI:  [10.1177/0022466919883397](https://doi.org/10.1177/0022466919883397)

* Rodgers, D. B., Datchuk, S. M., & Rila, A. L. (2021). Effects of a text-writing fluency intervention for postsecondary students with intellectual and developmental disabilities. *Exceptionality, 29*(4), 310-325. DOI: [10.1080/09362835.2020.1850451](https://doi.org/10.1080/09362835.2020.1850451)

* Rodriguez, B. J., & Anderson, C. M. (2014). Integrating a social behavior intervention during small group academic instruction using a total group criterion intervention. *Journal of Positive Behavior Interventions, 16*(4), 234-245. DOI: [10.1177/1098300713492858](http://dx.doi.org/10.1177/1098300713492858)

* Saddler, B., Behforooz, B., & Asaro, K. (2008). The effects of sentence-combining instruction on the writing of fourth-grade students with writing difficulties. *The Journal of Special Education, 42*(2), 79-90. DOI: [10.1177/0022466907310371](http://dx.doi.org/10.1177/0022466907310371)

* Schutte, N. S., Malouff, J. M., & Brown, R. F. (2008). Efficacy of an emotion-focused treatment for prolonged fatigue. *Behavior Modification, 32*(5), 699-713. DOI: [10.1177/0145445508317133](http://dx.doi.org/10.1177/0145445508317133)

* Thiemann, K.S., & Goldstein, H. (2001). Social stories, written text cues, and video feedback: effects on social communication of children with Autism. *Journal of Applied Behavior Analysis, 34*(4), 425-446. DOI: [10.1901/jaba.2001.34-425](https://onlinelibrary.wiley.com/doi/abs/10.1901/jaba.2001.34-425)

* Thorne, S., & Kamps, D. (2008). The effects of a group contingency intervention on academic engagement and problem behavior of at-risk students. *Behavior Analysis in Practice, 1*(2), 12-18. DOI: [10.1007/BF03391723](http://dx.doi.org/10.1007/BF03391723)
