### Methodological references

* Chen, M., Pustejovsky, J. E., Klingbeil, D. A., & Van Norman, E. (2023). Between-case standardized mean differences: Flexible methods for single-case designs. _Journal of School Psychology, 98_, 16-38. https://doi.org/10.1016/j.jsp.2023.02.002

* Hedges, L. V, Pustejovsky, J. E., & Shadish, W. R. (2012). A standardized mean difference effect size for single case designs. _Research Synthesis Methods, 3_, 224–239. https://doi.org/10.1002/jrsm.1052

* Hedges, L. V, Pustejovsky, J. E., & Shadish, W. R. (2013). A standardized mean difference effect size for multiple baseline designs across individuals. )Research Synthesis Methods, 4_)(4), 324–341. https://doi.org/10.1002/jrsm.1086

* Pustejovsky, J. E., Hedges, L. V, & Shadish, W. R. (2014). Design-comparable effect sizes in multiple baseline designs: A general modeling framework. Journal of Educational and Behavioral Statistics, 39_(5), 368–393. https://doi.org/10.3102/1076998614547577

* Shadish, W. R., Hedges, L. V, Pustejovsky, J. E., Boyajian, J. G., Sullivan, K. J., Andrade, A., & Barrientos, J. L. (2014). A d-statistic for single-case designs that is equivalent to the usual between-groups d-statistic. _Neuropsychological Rehabilitation: An International Journal, 24_(3-4), 528-553. https://doi.org/10.1080/09602011.2013.819021

* Shadish, W. R., Hedges, L. V, & Pustejovsky, J. E. (2014). Analysis and meta-analysis of single-case designs with a standardized mean difference statistic: A primer and applications. _Journal of School Psychology, 52_, 123–147. https://doi.org/10.1016/j.jsp.2013.11.005
