### Demonstration videos

The following videos provide instructions for how to install R, RStudio, and the scdhlm app on your computer:

* Mac: https://www.youtube.com/watch?v=R0n9eo4oB7k 
* Windows: https://www.youtube.com/watch?v=DhrIfIXjF4c

The following videos provide detailed demonstrations of how to use the scdhlm app to estimate a between-case standardized mean difference effect size:

* A model without time trends: https://www.youtube.com/watch?v=arDE6uhLLAc
* A model that includes time trends: https://www.youtube.com/watch?v=DsFJO2MBkjM

