---
output: md_document
---

### scdhlm

Version `r packageVersion("scdhlm")`

Designed by James E. Pustejovsky and Man Chen, with contributions from Bethany Hamilton and Paulina Grekov.

* pustejovsky@wisc.edu
* https://jepusto.com

[Source code available on Github](https://github.com/jepusto/scdhlm/tree/master/inst/shiny-examples/scdhlm)

_Your comments, suggestions, and feedback are welcome._


### Acknowledgement

<img src="https://raw.githubusercontent.com/jepusto/scdhlm/master/images/IES_InstituteOfEducationSciences_RGB.svg" width="30%" align = "right" style = "margin: 0px 10px" alt = "Institute of Education Sciences logo"/>

The development of this application was supported in part by the Institute of Education Sciences, U.S. Department of Education, through [Grant R324U190002](https://ies.ed.gov/funding/grantsearch/details.asp?ID=3358) to the University of Oregon. The contents of the application do not necessarily represent the views of the Institute or the U.S. Department of Education.

### Suggested citation

Pustejovsky, J. E., Chen, M., Hamilton, B., & Grekov, P. (`r substr(packageDate("scdhlm"),1,4)`). scdhlm: A web-based calculator for between-case standardized mean differences (Version `r packageVersion("scdhlm")`) [Web application]. https://jepusto.shinyapps.io/scdhlm

### Tutorial paper

Valentine, J. C., Tanner-Smith, E. E., & Pustejovsky, J. E. (2016). [Between-case standardized mean difference effect sizes for single-case designs: A primer and tutorial using the scdhlm web application](https://campbellcollaboration.org/library/effect-sizes-single-case-designs-campbell-discussion-paper-1.html). Oslo, Norway: The Campbell Collaboration. DOI: 10.4073/cmpn.2016.3
