% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scdhlm-package.r
\docType{data}
\name{MB4time}
\alias{MB4time}
\title{MB4 simulation time}
\format{
A data frame
}
\description{
MB4 simulation time
}
\keyword{datasets}
