% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scdhlm-package.r
\docType{data}
\name{MB2time}
\alias{MB2time}
\title{MB2 simulation time}
\format{
A data frame
}
\description{
MB2 simulation time
}
\keyword{datasets}
